@@ -156,6 +156,6 @@ class BertSTEMForTextClassification:
                                                         return_attention_mask = True,   # Construct attn. masks.
                                                         return_tensors = 'pt')
 
-        logits = self._model(encoded_dict['input_ids'])['logits']
+        logits = self._model(encoded_text['input_ids'])['logits']
         
         return(torch.nn.Softmax()(logits))
